@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.90, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -383,9 +383,9 @@ mav_avatarDraw
   mav_avatarSetVelocity (a, mav_vectorSet(tdp->x,tdp->y,tdp->z), 1);
 #endif /* DEVA */
 
-  dr.x= mav_win_current->vp->eye.x-a->matrix.mat[3][0];
-  dr.y= mav_win_current->vp->eye.y-a->matrix.mat[3][1];
-  dr.z= mav_win_current->vp->eye.z-a->matrix.mat[3][2];
+  dr.x= mav_win_current->vp->eye.x-a->matrix.mat[MAV_MATRIX_XCOMP];
+  dr.y= mav_win_current->vp->eye.y-a->matrix.mat[MAV_MATRIX_YCOMP];
+  dr.z= mav_win_current->vp->eye.z-a->matrix.mat[MAV_MATRIX_ZCOMP];
   dd= dr.x*dr.x+dr.y*dr.y+dr.z*dr.z;
 
   a->drawn= 1;
@@ -669,9 +669,9 @@ mav_avatarUpdatePosition
   MAV_vector new_position;
 
   /* get last position from matrix */
-  position.x= avatar->matrix.mat[3][0];
-  position.y= avatar->matrix.mat[3][1];
-  position.z= avatar->matrix.mat[3][2];
+  position.x= avatar->matrix.mat[MAV_MATRIX_XCOMP];
+  position.y= avatar->matrix.mat[MAV_MATRIX_YCOMP];
+  position.z= avatar->matrix.mat[MAV_MATRIX_ZCOMP];
 
   /* work out the new position */
   time= mav_getTimer();
@@ -712,7 +712,7 @@ mav_avatarAnimate
       direction.x /= s;
       direction.y /= s;
       direction.z /= s;
-      angle= -57.29577951*acos(direction.z);
+      angle= 57.29577951*acos(direction.z);
       if (direction.x < 0.0) angle= -angle;
     }
   else
