@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.90, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -741,23 +741,23 @@ void Make_Streets(char *strfile, char *lstfile)
 	  newy= vy1+current_spacing_y;
 
 	  /* set up transformation matrix */
-	  character->matrix= mav_matrixSet(0.0, 0.0, 180.0*dir/MAV_PI+90.0, newx, 0.0, newy);
+	  character->matrix= mav_matrixSet(0.0, 0.0, -(180.0*dir/MAV_PI+90.0), newx, 0.0, newy);
 
 	  /* scale matrix */
 	  character->matrix.mat[0][0] *= width;
-	  character->matrix.mat[0][1] *= width;
-	  character->matrix.mat[0][2] *= width;
-	  character->matrix.mat[0][3] *= width;
+	  character->matrix.mat[1][0] *= width;
+	  character->matrix.mat[2][0] *= width;
+	  character->matrix.mat[3][0] *= width;
 	  
-	  character->matrix.mat[1][0] *= height;
+	  character->matrix.mat[0][1] *= height;
 	  character->matrix.mat[1][1] *= height;
-	  character->matrix.mat[1][2] *= height;
-	  character->matrix.mat[1][3] *= height;
+	  character->matrix.mat[2][1] *= height;
+	  character->matrix.mat[3][1] *= height;
 	  
-	  character->matrix.mat[2][0] *= depth;
-	  character->matrix.mat[2][1] *= depth;
+	  character->matrix.mat[0][2] *= depth;
+	  character->matrix.mat[1][2] *= depth;
 	  character->matrix.mat[2][2] *= depth;
-	  character->matrix.mat[2][3] *= depth;
+	  character->matrix.mat[3][2] *= depth;
 
 	  /* create Maverik object and place in SMS */
 	  mav_SMSObjectAdd(city_build, mav_objectNew(mav_class_character, character));
