@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.90, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -1601,23 +1601,23 @@ void MakeAllStreets()
        newy= vy1+current_spacing_y;
 
        /* set up transformation matrix */
-       character->matrix= mav_matrixSet(0.0, 0.0, 180.0*dir/MAV_PI+90.0, newx, 0.0, newy);
+       character->matrix= mav_matrixSet(0.0, 0.0, -(180.0*dir/MAV_PI+90.0), newx, 0.0, newy);
 
        /* scale matrix */
        character->matrix.mat[0][0] *= width;
-       character->matrix.mat[0][1] *= width;
-       character->matrix.mat[0][2] *= width;
-       character->matrix.mat[0][3] *= width;
+       character->matrix.mat[1][0] *= width;
+       character->matrix.mat[2][0] *= width;
+       character->matrix.mat[3][0] *= width;
 	  
-       character->matrix.mat[1][0] *= height;
+       character->matrix.mat[0][1] *= height;
        character->matrix.mat[1][1] *= height;
-       character->matrix.mat[1][2] *= height;
-       character->matrix.mat[1][3] *= height;
+       character->matrix.mat[2][1] *= height;
+       character->matrix.mat[3][1] *= height;
 	  
-       character->matrix.mat[2][0] *= depth;
-       character->matrix.mat[2][1] *= depth;
+       character->matrix.mat[0][2] *= depth;
+       character->matrix.mat[1][2] *= depth;
        character->matrix.mat[2][2] *= depth;
-       character->matrix.mat[2][3] *= depth;
+       character->matrix.mat[3][2] *= depth;
 
        /* create Maverik object and place in SMS */
        mav_SMSCallbackObjectAddExec(city_build, mav_objectNew(mav_class_character, character));
@@ -2251,23 +2251,23 @@ int mav_LCityDraw(MAV_object *obj, MAV_drawInfo *di)
     
     if (drawMap) {
         m.mat[0][0]= right.x;
-        m.mat[0][1]= up.x;
-        m.mat[0][2]= -view.x;
+        m.mat[0][1]= right.y;
+        m.mat[0][2]= right.z;
         m.mat[0][3]= 0.0;
 
-        m.mat[1][0]= right.y;
+        m.mat[1][0]= up.x;
         m.mat[1][1]= up.y;
-        m.mat[1][2]= -view.y;
+        m.mat[1][2]= up.z;
         m.mat[1][3]= 0.0;
 
-        m.mat[2][0]= right.z;
-        m.mat[2][1]= up.z;
+        m.mat[2][0]= -view.x;
+        m.mat[2][1]= -view.y;
         m.mat[2][2]= -view.z;
         m.mat[2][3]= 0.0;
 
-        m.mat[3][0]= 0;
-        m.mat[3][1]= 0;
-        m.mat[3][2]= 0;
+        m.mat[3][0]= 0.0;
+        m.mat[3][1]= 0.0;
+        m.mat[3][2]= 0.0;
         m.mat[3][3]= 1.0;
 
         mav_gfxMatrixLoad(m);
@@ -2674,7 +2674,7 @@ int keyPress(MAV_object *o, MAV_keyboardEvent *ke)
   return 1;
 }
 
-void main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
   MAV_SMS *sms;
   MAV_object *o;
